@@ -1,13 +1,11 @@
 -- | Bit-level type casts and byte layout string typecasts.
-module Sound.OSC.Coding.Cast (f32_w32,w32_f32
-                             ,f64_w64,w64_f64
-                             ,str_cstr,cstr_str
-                             ,str_pstr,pstr_str) where
+module Sound.OSC.Coding.Cast where
 
-import qualified Data.Binary.IEEE754 as I {- data-binary-ieee754 -}
 import Data.Char {- base -}
 import Data.Word {- base -}
 
+import qualified Data.Binary.IEEE754 as I {- data-binary-ieee754 -}
+
 -- | The IEEE byte representation of a float.
 f32_w32 :: Float -> Word32
 f32_w32 = I.floatToWord
@@ -24,8 +22,7 @@ f64_w64 = I.doubleToWord
 w64_f64 :: Word64 -> Double
 w64_f64 = I.wordToDouble
 
--- | Transform a haskell string into a C string (a null suffixed byte
---   string).
+-- | Transform a haskell string into a C string (a null suffixed byte string).
 str_cstr :: String -> [Word8]
 str_cstr s = map (fromIntegral . ord) s ++ [0]
 
@@ -33,8 +30,7 @@ str_cstr s = map (fromIntegral . ord) s ++ [0]
 cstr_str :: [Word8] -> String
 cstr_str = map (chr . fromIntegral) . takeWhile (/= 0)
 
--- | Transform a haskell string to a pascal string (a length prefixed
---   byte string).
+-- | Transform a haskell string to a pascal string (a length prefixed byte string).
 str_pstr :: String -> [Word8]
 str_pstr s = fromIntegral (length s) : map (fromIntegral . ord) s
 
